html, body {
    height: 100%;
    margin: 0;
    padding: 0;
    overflow: hidden;
    font-family: Helvetica, Arial, sans-serif;
}

*, *:before, *:after {
    box-sizing: border-box;
}

body {
    padding: 0 0.5em;
    overflow: auto;
}

h1, h2, h3, h4, h5, h6 {
    margin: 0;
    padding: 0;
    margin-bottom: 0.5em;
}


